# Keyboard Shortcuts

## Navigation

| Key | Action |
|-----|--------|
| Left/Right | Previous/Next frame (T) |
| Up/Down | Previous/Next z-plane (Z) |
| Shift + Arrow | Jump 10 frames/planes |

## File

| Key | Action |
|-----|--------|
| o | Open file |
| Shift + O | Open folder |
| s | Save as |

## View

| Key | Action |
|-----|--------|
| m | Toggle metadata viewer |
| p | Toggle side panel |
| v | Reset vmin/vmax |
| k | Show keybinds |
| h | Show help |

## Mouse

- **Scroll**: Zoom
- **Drag**: Pan
- **Right-click**: Context menu
